OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Выяўлена новае месцазнаходжанне ўваходу",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Выяўлены новы ўваход у ваш уліковы запіс. IP-адрас %s быў класіфікаваны як падазроны. Калі гэта былі вы, можаце праігнараваць гэта паведамленне. У адваротным выпадку вам варта змяніць пароль.",
    "Open %s ↗" : "Адкрыць %s ↗",
    "Suspicious Login" : "Падазроны ўваход",
    "New login detected" : "Выяўлены новы ўваход"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
